@@ -21,6 +21,7 @@ file_trajectory = read.read_parameters(input_file)[7]
 file_initial_conf = read.read_parameters(input_file)[8]
 DT = read.read_parameters(input_file)[9]
 Nb = read.read_parameters(input_file)[10]
+appendix = read.read_parameters(input_file)[11]
 
 tot_atoms_uc = int(np.sum(n_atom_unit_cell)) 
 N1N2N3 = N1*N2*N3 # Number of cells
@@ -38,6 +39,7 @@ print(' Number of atoms per unit cell', n_atom_unit_cell)
 print(' Supercell: ', N1, N2, N3)
 print(' k path: ', [x.tolist() for x in kinput_scaled])
 print(' Extent of timestep [ps]: ', DT*2.418884254*1e-05)
+print(' Appendix: ', appendix)
 print()
 
 
@@ -53,8 +55,11 @@ SCell, Ruc, Suc, R0, R0_repeat, S0, masses, masses_uc = read.read_SPOSCAR_and_ma
 
 # =============================================================================
 # MD positions and velocities
-Rt = np.loadtxt(file_trajectory)[:,1:]
-Num_timesteps = int(len(Rt[:,0]))
+# # Rt = np.loadtxt(file_trajectory)[:,1:]  #  old version of data_pos
+# # Num_timesteps = int(len(Rt[:,0]))
+Rt = np.loadtxt(file_trajectory, skiprows=N*0) #  new version of Cartesian_0
+Num_timesteps = int(len(Rt[:,0])/N)
+Rt = Rt.reshape(Num_timesteps, N*3)
 print(' Number of timesteps of simulation: ', Num_timesteps)
 tall = np.arange(Num_timesteps)*DT*2.418884254*1e-05 #conversion to picoseconds
 dt_ps = tall[1]-tall[0]
@@ -125,9 +130,9 @@ for i in range(Nqs_path):
         
         popt, perr = util.fit_to_lorentzian(x_data, y_data, k, n)
         Params[:,n] = popt
-        #now you go apply to Voigt equation for the sigmas
-        fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig=popt[-1]*0.42)
-        Params[-1,n] = fl
+        # #now you go apply to Voigt equation for the sigmas, but you dont do this anymore
+        # fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig=popt[-1]*0.42)
+        # Params[-1,n] = fl
         
         x_avg, std = util.get_avg_std(x_data, y_data, k, n)
         raw_data_Params[0,n], raw_data_Params[-1,n] = x_avg, std
@@ -152,11 +157,11 @@ for i in range(Nqs_path):
     Zqs[i,:,0] = Sq[0:meta]
     Zqs[i,:,1:] = Sq_proj[0:meta,:]
 
-util.save_quasiparticles('Zqs', quasiparticles_kpoints, Zqs)
-util.save_quasiparticles('quasiparticles', quasiparticles_kpoints, quasiparticles_info)  
-util.save_quasiparticles('non_quasiparticles', quasiparticles_kpoints, raw_data_info)  
-util.save('C_t', np.vstack((tall[0:len(C)],C)).T)
-util.save('ZS', ZS)
+util.save_quasiparticles('Zqs'+appendix, quasiparticles_kpoints, Zqs)
+util.save_quasiparticles('quasiparticles'+appendix, quasiparticles_kpoints, quasiparticles_info)  
+util.save_quasiparticles('non_quasiparticles'+appendix, quasiparticles_kpoints, raw_data_info)  
+util.save('C_t'+appendix, np.vstack((tall[0:len(C)],C)).T)
+util.save('ZS'+appendix, ZS)
 # =============================================================================
     
 
@@ -226,6 +231,6 @@ for i in range(Nqs):
 # K_renorm writing to file
 K_renorm = util.get_K_renorm_old(tot_atoms_uc,N1,N2,N3, SCell, R0, kpoints, Ds)
 print('Calculated renormalized FORCE CONSTANTS')
-util.save('K_renorm', K_renorm)
+util.save('K_renorm'+appendix, K_renorm)
 # =============================================================================
 
