@@ -441,6 +441,23 @@ def fit_to_lorentzian(x_data, y_data, k, n):
     perr = np.sqrt(np.diag(pcov))
     return popt, perr
 
+
+def fit_to_gaussian(x_data, y_data, k, n):
+    try:
+        if(n in [0,1,2] and np.allclose(k, [0,0,0])): #if acoustic modes at Gamma, don't fit anything
+                popt, pcov = np.array([0.0001, 0, 0.0001]), np.zeros((3,3))
+        else:
+            popt, pcov = curve_fit(norm_gaussian, x_data, y_data)
+    except RuntimeError:
+        print('\t\tWasnt able to fit to Gaussian mode '+str(n)+'\n\n')
+        x0 = x_data[np.argwhere(y_data==y_data.max())]
+        y0 = y_data.max()
+        popt, pcov = np.array([x0,y0,0.0001]), np.zeros((3,3))
+    perr = np.sqrt(np.diag(pcov))
+    return popt, perr
+
+
+
 def odd_num_steps(Num_timesteps):
     if((Num_timesteps-1)%2 == 0): 
         Num_steps = Num_timesteps -1
